Learn R Programming

LogisticEnsembles (version 1.0.0)

German_Credit_Risk: German_Credit_Risk-This dataset classifies people described by a set of attributes as good or bad credit risks. #'

Description

This data set originally came from Professor Hofmann, and is available in several locations, including the UCI Machine Learning Repository I cleaned the data set up, which included naming each of the columns, and removing white spaces from the names of the columns.

The data set has 999 observations of 21 columns of data.The 21st column, "Class" is the target column in the data. Acknowledgements https://dutangc.github.io/CASdatasets/reference/credit.html

Attribute1

Status of existing checking account

Attribute2

Duration (in months)

Attribute3

Credit history

Attribute4

Purpose

Attribute5

Credit amount

Attribute6

Savings accounts/bonds

Attribute7

Present employment since

Attribute8

Installment rate in percentage of disposable income

Attribute9

Personal status and sex

Attribute10

Other debtors / guarantors

Attribute11

Present residence since

Attribute12

Property

Attribute13

Age (in years)

Attribute14

Other installment plans

Attribute15

Housing

Attribute16

Number of existing credits at this bank

Attribute17

Job

Attribute18

Number of people being liable to provide maintenance for

Attribute19

Telephone

Attribute20

Foreign worker

Class

1 = Good, 0 = Bad

Usage

German_Credit_Risk

Arguments

Format

An object of class data.frame with 999 rows and 21 columns.